@@ -163,7 +163,7 @@ class Bubble:
         # Get the file URL
         # try:
         file_url = path + file
-        print(path,file)
+
         ftype = mimetypes.guess_type(file_url, strict=True)[0]
         # except FileNotFoundError:
         #     print('e')
@@ -212,7 +212,7 @@ class Bubble:
                       fontsize=conf['labeltext_size'],
                       labelpad=conf['labelpad'])
 
-    def pic_save(self, conf, path_img, output_name, file_type):
+    def pic_save(self, conf,output_name):
         # save the picture in specific file type
 
         # xtricks and yticks font size
@@ -220,17 +220,17 @@ class Bubble:
         plt.yticks(fontsize=self.conf['ytrick_fontsize'])
 
         # title
-        plt.title(conf['plot_title'], fontsize=self.conf['title_size'])
+        # plt.title(conf['plot_title'], fontsize=self.conf['title_size'])
 
         # save the plot
 
-        plt.savefig(path_img + output_name + file_type)
+        plt.savefig(output_name)
         plt.show()
 
     # def conf_setting(self, key, value):
     #     self.conf_set.update(key / value)
 
-    def bubble_plot(self, file, path=None, file_type='.pdf', path_img=None, x_col_name=None, y_col_name=None,
+    def bubble_plot(self, path=None, file_type='.pdf', path_img=None, x_col_name=None, y_col_name=None,
                     bubble_col=None, x_label='x label',
                     y_label='y label', bubble_name=None, legend_title='title', output_name='output', **kwargs):
         """Bubble chart with each bubble name and sizes 
@@ -271,8 +271,8 @@ class Bubble:
             bubble_col = header_list[3]
         if bubble_name is None:
             bubble_name = header_list[0]
-        if path is None:
-            path = self.path
+        # if path is None:
+        #     path = self.path
         if path_img is None:
             path_img = path
 
@@ -351,7 +351,7 @@ class Bubble:
                             title=conf['bubbleszie_legend_title'],
                             fontsize=conf['legend_size'])
 
-        self.pic_save(conf, path_img, output_name, file_type)
+        self.pic_save(conf, path_img)
 
     def bubble_category(self, file, path=None, file_type='.pdf', path_img=None, x_col_name=None, y_col_name=None,
                         bubble_col=None,
