@@ -103,7 +103,7 @@ class Scat:
         plt.plot(X, Y_pred, color='#20639B')
 
     def plot(self,
-                     file,
+
                      x_col_name = None,
                      y_col_name = None,
                      x_label = None,
@@ -242,7 +242,7 @@ class Scat:
 
         # if the output name is empty, the output name will be file name
         if output_name == None:
-            output_name = file.split(".")[0]
+            output_name ='output'
 
         # save the plot
         plt.tight_layout()
@@ -253,7 +253,6 @@ class Scat:
         plt.show()
 
     def scatter_category(self,
-                         file,
                          x_col_name,
                          y_col_name,
                          x_label,
